@@ -102,7 +102,7 @@ gedit_style_scheme_manager_list_schemes_sorted (GtkSourceStyleSchemeManager *man
 	const gchar * const * scheme_ids;
 	GSList *schemes = NULL;
 
-	g_return_val_if_fail (GTK_IS_SOURCE_STYLE_SCHEME_MANAGER (manager), NULL);
+	g_return_val_if_fail (GTK_SOURCE_IS_STYLE_SCHEME_MANAGER (manager), NULL);
 
 	scheme_ids = gtk_source_style_scheme_manager_get_scheme_ids (manager);
 	
@@ -253,7 +253,7 @@ _gedit_style_scheme_manager_install_scheme (GtkSourceStyleSchemeManager *manager
 
 	const gchar* const *ids;
 
-	g_return_val_if_fail (GTK_IS_SOURCE_STYLE_SCHEME_MANAGER (manager), NULL);
+	g_return_val_if_fail (GTK_SOURCE_IS_STYLE_SCHEME_MANAGER (manager), NULL);
 	g_return_val_if_fail (fname != NULL, NULL);
 
 	dirname = g_path_get_dirname (fname);
@@ -342,7 +342,7 @@ _gedit_style_scheme_manager_uninstall_scheme (GtkSourceStyleSchemeManager *manag
 	GtkSourceStyleScheme *scheme;
 	const gchar *filename;
 
-	g_return_val_if_fail (GTK_IS_SOURCE_STYLE_SCHEME_MANAGER (manager), FALSE);
+	g_return_val_if_fail (GTK_SOURCE_IS_STYLE_SCHEME_MANAGER (manager), FALSE);
 	g_return_val_if_fail (id != NULL, FALSE);
 
 	scheme = gtk_source_style_scheme_manager_get_scheme (manager, id);
