@@ -5,7 +5,7 @@
  * it under the terms of the GNU General Public License as published by
  * the Free Software Foundation; either version 2, or (at your option)
  * any later version.
- * 
+ *
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
@@ -22,24 +22,18 @@
 
 #include "gedit-check-update-plugin.h"
 
-#include <glib/gi18n-lib.h>
+#include <glib/gi18n.h>
+#include <gedit/gedit-window.h>
+#include <gedit/gedit-window-activatable.h>
 #include <gedit/gedit-debug.h>
 #include <gedit/gedit-utils.h>
 #include <libsoup/soup.h>
 #include <gtk/gtk.h>
 #include <stdlib.h>
 
-#include <gedit/gseal-gtk-compat.h>
-
-#if !GTK_CHECK_VERSION(2, 17, 1)
-#include <gedit/gedit-message-area.h>
-#endif
-
 #define CHECKUPDATE_BASE_SETTINGS	"org.gnome.gedit.plugins.checkupdate"
 #define CHECKUPDATE_KEY_IGNORE_VERSION	"ignore-version"
 
-#define WINDOW_DATA_KEY "GeditCheckUpdatePluginWindowData"
-
 #define VERSION_PLACE "<a href=\"[0-9]\\.[0-9]+/\">"
 
 #ifdef G_OS_WIN32
@@ -59,37 +53,33 @@
 				GEDIT_TYPE_CHECK_UPDATE_PLUGIN,		\
 				GeditCheckUpdatePluginPrivate))
 
-GEDIT_PLUGIN_REGISTER_TYPE (GeditCheckUpdatePlugin, gedit_check_update_plugin)
+static void gedit_window_activatable_iface_init (GeditWindowActivatableInterface *iface);
+
+G_DEFINE_DYNAMIC_TYPE_EXTENDED (GeditCheckUpdatePlugin,
+				gedit_check_update_plugin,
+				PEAS_TYPE_EXTENSION_BASE,
+				0,
+				G_IMPLEMENT_INTERFACE_DYNAMIC (GEDIT_TYPE_WINDOW_ACTIVATABLE,
+							       gedit_window_activatable_iface_init))
+
 
 struct _GeditCheckUpdatePluginPrivate
 {
 	SoupSession *session;
 
 	GSettings *settings;
-};
 
-typedef struct
-{
-	GeditCheckUpdatePlugin *plugin;
+	GeditWindow *window;
 
 	gchar *url;
 	gchar *version;
-} WindowData;
+};
 
-static void
-free_window_data (gpointer data)
+enum
 {
-	WindowData *window_data;
-
-	if (data == NULL)
-		return;
-
-	window_data = (WindowData *)data;
-
-	g_free (window_data->url);
-	g_free (window_data->version);
-	g_slice_free (WindowData, data);
-}
+	PROP_0,
+	PROP_WINDOW
+};
 
 static void
 gedit_check_update_plugin_init (GeditCheckUpdatePlugin *plugin)
@@ -120,35 +110,81 @@ gedit_check_update_plugin_dispose (GObject *object)
 		g_object_unref (plugin->priv->settings);
 		plugin->priv->settings = NULL;
 	}
+	
+	if (plugin->priv->window != NULL)
+	{
+		g_object_unref (plugin->priv->window);
+		plugin->priv->window = NULL;
+	}
 
 	gedit_debug_message (DEBUG_PLUGINS,
 			     "GeditCheckUpdatePlugin disposing");
-	
+
 	G_OBJECT_CLASS (gedit_check_update_plugin_parent_class)->dispose (object);
 }
 
 static void
 gedit_check_update_plugin_finalize (GObject *object)
 {
+	GeditCheckUpdatePlugin *plugin = GEDIT_CHECK_UPDATE_PLUGIN (object);
+
 	gedit_debug_message (DEBUG_PLUGINS,
 			     "GeditCheckUpdatePlugin finalizing");
 
+	g_free (plugin->priv->url);
+	g_free (plugin->priv->version);
+
 	G_OBJECT_CLASS (gedit_check_update_plugin_parent_class)->finalize (object);
 }
 
+static void
+gedit_check_update_plugin_set_property (GObject      *object,
+                                        guint         prop_id,
+                                        const GValue *value,
+                                        GParamSpec   *pspec)
+{
+	GeditCheckUpdatePlugin *plugin = GEDIT_CHECK_UPDATE_PLUGIN (object);
+
+	switch (prop_id)
+	{
+		case PROP_WINDOW:
+			plugin->priv->window = GEDIT_WINDOW (g_value_dup_object (value));
+			break;
+
+		default:
+			G_OBJECT_WARN_INVALID_PROPERTY_ID (object, prop_id, pspec);
+			break;
+	}
+}
+
+static void
+gedit_check_update_plugin_get_property (GObject    *object,
+                                        guint       prop_id,
+                                        GValue     *value,
+                                        GParamSpec *pspec)
+{
+	GeditCheckUpdatePlugin *plugin = GEDIT_CHECK_UPDATE_PLUGIN (object);
+
+	switch (prop_id)
+	{
+		case PROP_WINDOW:
+			g_value_set_object (value, plugin->priv->window);
+			break;
+
+		default:
+			G_OBJECT_WARN_INVALID_PROPERTY_ID (object, prop_id, pspec);
+			break;
+	}
+}
+
 static void
 set_contents (GtkWidget *infobar,
 	      GtkWidget *contents)
 {
-#if !GTK_CHECK_VERSION (2, 17, 1)
-	gedit_message_area_set_contents (GEDIT_MESSAGE_AREA (infobar),
-					 contents);
-#else
 	GtkWidget *content_area;
-	
+
 	content_area = gtk_info_bar_get_content_area (GTK_INFO_BAR (infobar));
 	gtk_container_add (GTK_CONTAINER (content_area), contents);
-#endif
 }
 
 static void
@@ -202,28 +238,24 @@ set_message_area_text_and_icon (GtkWidget        *message_area,
 		gtk_label_set_selectable (GTK_LABEL (secondary_label), TRUE);
 		gtk_misc_set_alignment (GTK_MISC (secondary_label), 0, 0.5);
 	}
-	
+
 	set_contents (message_area, hbox_content);
 }
 
 static void
-on_response_cb (GtkWidget   *infobar,
-		gint         response_id,
-		GeditWindow *window)
+on_response_cb (GtkWidget              *infobar,
+		gint                    response_id,
+		GeditCheckUpdatePlugin *plugin)
 {
 	if (response_id == GTK_RESPONSE_YES)
 	{
 		GError *error = NULL;
-		WindowData *data;
-		
-		data = g_object_get_data (G_OBJECT (window),
-					  WINDOW_DATA_KEY);
 
 #ifdef OS_OSX
-		gedit_osx_show_url (data->url);
+		gedit_osx_show_url (plugin->priv->url);
 #else
-		gtk_show_uri (gtk_widget_get_screen (GTK_WIDGET (window)),
-			      data->url,
+		gtk_show_uri (gtk_widget_get_screen (GTK_WIDGET (plugin->priv->window)),
+			      plugin->priv->url,
 			      GDK_CURRENT_TIME,
 			      &error);
 #endif
@@ -231,10 +263,10 @@ on_response_cb (GtkWidget   *infobar,
 		{
 			GtkWidget *dialog;
 
-			dialog = gtk_message_dialog_new (GTK_WINDOW (window),
+			dialog = gtk_message_dialog_new (GTK_WINDOW (plugin->priv->window),
 							 GTK_DIALOG_DESTROY_WITH_PARENT,
 							 GTK_MESSAGE_ERROR,
-							 GTK_BUTTONS_CLOSE, 
+							 GTK_BUTTONS_CLOSE,
 							 _("There was an error displaying the URI."));
 
 			gtk_message_dialog_format_secondary_text (GTK_MESSAGE_DIALOG (dialog),
@@ -254,19 +286,11 @@ on_response_cb (GtkWidget   *infobar,
 	}
 	else if (response_id == GTK_RESPONSE_NO)
 	{
-		WindowData *data;
-		
-		data = g_object_get_data (G_OBJECT (window), WINDOW_DATA_KEY);
-
-		g_settings_set_string (data->plugin->priv->settings,
+		g_settings_set_string (plugin->priv->settings,
 				       CHECKUPDATE_KEY_IGNORE_VERSION,
-				       data->version);
+				       plugin->priv->version);
 	}
 
-	g_object_set_data (G_OBJECT (window),
-			   WINDOW_DATA_KEY,
-			   NULL);
-
 	gtk_widget_destroy (infobar);
 }
 
@@ -276,26 +300,10 @@ create_infobar (GeditWindow *window,
 {
 	GtkWidget *infobar;
 	gchar *message;
-
-#if !GTK_CHECK_VERSION (2, 17, 1)
-	infobar = gedit_message_area_new ();
-	
-	gedit_message_area_add_stock_button_with_text (GEDIT_MESSAGE_AREA (infobar),
-						       _("_Download"),
-						       GTK_STOCK_SAVE,
-						       GTK_RESPONSE_YES);
-	gedit_message_area_add_stock_button_with_text (GEDIT_MESSAGE_AREA (infobar),
-						       _("_Ignore Version"),
-						       GTK_STOCK_DISCARD,
-						       GTK_RESPONSE_NO);
-	gedit_message_area_add_button (GEDIT_MESSAGE_AREA (infobar),
-				       GTK_STOCK_CANCEL,
-				       GTK_RESPONSE_CANCEL);
-#else
 	GtkWidget *button;
 
 	infobar = gtk_info_bar_new ();
-	
+
 	button = gedit_gtk_button_new_with_stock_icon (_("_Download"),
 						       GTK_STOCK_SAVE);
 	gtk_widget_show (button);
@@ -315,10 +323,9 @@ create_infobar (GeditWindow *window,
 	gtk_info_bar_add_button (GTK_INFO_BAR (infobar),
 				 GTK_STOCK_CANCEL,
 				 GTK_RESPONSE_CANCEL);
-	
+
 	gtk_info_bar_set_message_type (GTK_INFO_BAR (infobar),
 				       GTK_MESSAGE_INFO);
-#endif
 
 	message = g_strdup_printf ("%s (%s)", _("There is a new version of gedit"), version);
 	set_message_area_text_and_icon (infobar,
@@ -333,7 +340,7 @@ create_infobar (GeditWindow *window,
 	g_signal_connect (infobar, "response",
 			  G_CALLBACK (on_response_cb),
 			  window);
-	
+
 	return infobar;
 }
 
@@ -342,9 +349,9 @@ pack_infobar (GtkWidget *window,
 	      GtkWidget *infobar)
 {
 	GtkWidget *vbox;
-	
+
 	vbox = gtk_bin_get_child (GTK_BIN (window));
-	
+
 	gtk_box_pack_start (GTK_BOX (vbox), infobar, FALSE, FALSE, 0);
 	gtk_box_reorder_child (GTK_BOX (vbox), infobar, 2);
 }
@@ -356,20 +363,20 @@ get_file (const gchar *text,
 	GRegex *regex;
 	GMatchInfo *match_info;
 	gchar *word = NULL;
-	
+
 	regex = g_regex_new (regex_place, 0, 0, NULL);
 	g_regex_match (regex, text, 0, &match_info);
 	while (g_match_info_matches (match_info))
 	{
 		g_free (word);
-		
+
 		word = g_match_info_fetch (match_info, 0);
-		
+
 		g_match_info_next (match_info, NULL);
 	}
 	g_match_info_free (match_info);
 	g_regex_unref (regex);
-	
+
 	return word;
 }
 
@@ -381,16 +388,16 @@ get_numbers (const gchar *version,
 {
 	gchar **split;
 	gint num = 2;
-	
+
 	if (micro != NULL)
 		num = 3;
-	
+
 	split = g_strsplit (version, ".", num);
 	*major = atoi (split[0]);
 	*minor = atoi (split[1]);
 	if (micro != NULL)
 		*micro = atoi (split[2]);
-	
+
 	g_strfreev (split);
 }
 
@@ -402,7 +409,7 @@ newer_version (const gchar *v1,
 	gboolean newer = FALSE;
 	gint major1, minor1, micro1;
 	gint major2, minor2, micro2;
-	
+
 	if (v1 == NULL || v2 == NULL)
 		return FALSE;
 
@@ -429,7 +436,7 @@ newer_version (const gchar *v1,
 	{
 		newer = TRUE;
 	}
-	
+
 	return newer;
 }
 
@@ -437,21 +444,21 @@ static gchar *
 parse_file_version (const gchar *file)
 {
 	gchar *p, *aux;
-	
+
 	p = (gchar *)file;
-	
+
 	while (*p != '\0' && !g_ascii_isdigit (*p))
 	{
 		p++;
 	}
-	
+
 	if (*p == '\0')
 		return NULL;
-	
+
 	aux = g_strrstr (p, "-");
 	if (aux == NULL)
 		aux = g_strrstr (p, ".");
-	
+
 	return g_strndup (p, aux - p);
 }
 
@@ -463,42 +470,37 @@ get_ignore_version (GeditCheckUpdatePlugin *plugin)
 }
 
 static void
-parse_page_file (SoupSession *session,
-		 SoupMessage *msg,
-		 GeditWindow *window)
+parse_page_file (SoupSession            *session,
+		 SoupMessage            *msg,
+		 GeditCheckUpdatePlugin *plugin)
 {
 	if (msg->status_code == SOUP_STATUS_OK)
 	{
 		gchar *file;
 		gchar *file_version;
 		gchar *ignore_version;
-		WindowData *data;
-
-		data = g_object_get_data (G_OBJECT (window), WINDOW_DATA_KEY);
 
 		file = get_file (msg->response_body->data, FILE_REGEX);
 		file_version = parse_file_version (file);
-		ignore_version = get_ignore_version (data->plugin);
+		ignore_version = get_ignore_version (plugin);
 
 		if (newer_version (file_version, VERSION, TRUE) &&
 		    (ignore_version == NULL || *ignore_version == '\0' ||
 		     newer_version (file_version, ignore_version, TRUE)))
 		{
 			GtkWidget *infobar;
-			WindowData *data;
 			gchar *file_url;
 
-			data = g_object_get_data (G_OBJECT (window),
-						  WINDOW_DATA_KEY);
-			
-			file_url = g_strconcat (data->url, file, NULL);
+			file_url = g_strconcat (plugin->priv->url, file, NULL);
 
-			g_free (data->url);
-			data->url = file_url;
-			data->version = g_strdup (file_version);
-		
-			infobar = create_infobar (window, file_version);
-			pack_infobar (GTK_WIDGET (window), infobar);
+			g_free (plugin->priv->url);
+			plugin->priv->url = file_url;
+			plugin->priv->version = g_strdup (file_version);
+
+			infobar = create_infobar (plugin->priv->window,
+						  file_version);
+			pack_infobar (GTK_WIDGET (plugin->priv->window),
+						  infobar);
 			gtk_widget_show (infobar);
 		}
 
@@ -506,12 +508,6 @@ parse_page_file (SoupSession *session,
 		g_free (file_version);
 		g_free (file);
 	}
-	else
-	{
-		g_object_set_data (G_OBJECT (window),
-				   WINDOW_DATA_KEY,
-				   NULL);
-	}
 }
 
 static gboolean
@@ -520,14 +516,14 @@ is_unstable (const gchar *version)
 	gchar **split;
 	gint minor;
 	gboolean unstable = TRUE;;
-	
+
 	split = g_strsplit (version, ".", 2);
 	minor = atoi (split[1]);
 	g_strfreev (split);
-	
+
 	if ((minor % 2) == 0)
 		unstable = FALSE;
-	
+
 	return unstable;
 }
 
@@ -540,25 +536,25 @@ get_file_page_version (const gchar *text,
 	GString *string = NULL;
 	gchar *unstable = NULL;
 	gchar *stable = NULL;
-	
+
 	regex = g_regex_new (regex_place, 0, 0, NULL);
 	g_regex_match (regex, text, 0, &match_info);
 	while (g_match_info_matches (match_info))
 	{
 		gint end;
 		gint i;
-		
+
 		g_match_info_fetch_pos (match_info, 0, NULL, &end);
-		
+
 		string = g_string_new ("");
-		
+
 		i = end;
 		while (text[i] != '/')
 		{
 			string = g_string_append_c (string, text[i]);
 			i++;
 		}
-		
+
 		if (is_unstable (string->str))
 		{
 			g_free (unstable);
@@ -569,16 +565,16 @@ get_file_page_version (const gchar *text,
 			g_free (stable);
 			stable = g_string_free (string, FALSE);
 		}
-		
+
 		g_match_info_next (match_info, NULL);
 	}
 	g_match_info_free (match_info);
 	g_regex_unref (regex);
-	
+
 	if ((GEDIT_MINOR_VERSION % 2) == 0)
 	{
 		g_free (unstable);
-		
+
 		return stable;
 	}
 	else
@@ -587,102 +583,102 @@ get_file_page_version (const gchar *text,
 		if (newer_version (stable, unstable, FALSE))
 		{
 			g_free (unstable);
-			
+
 			return stable;
 		}
 		else
 		{
 			g_free (stable);
-		
+
 			return unstable;
 		}
 	}
 }
 
 static void
-parse_page_version (SoupSession *session,
-		    SoupMessage *msg,
-		    GeditWindow *window)
+parse_page_version (SoupSession            *session,
+		    SoupMessage            *msg,
+		    GeditCheckUpdatePlugin *plugin)
 {
 	if (msg->status_code == SOUP_STATUS_OK)
 	{
 		gchar *version;
 		SoupMessage *msg2;
-		WindowData *data;
 
-		data = g_object_get_data (G_OBJECT (window), WINDOW_DATA_KEY);
-		
 		version = get_file_page_version (msg->response_body->data,
 						 VERSION_PLACE);
-		
-		data->url = g_strconcat (GEDIT_URL, version, "/", NULL);
+
+		plugin->priv->url = g_strconcat (GEDIT_URL, version, "/", NULL);
 		g_free (version);
-		msg2 = soup_message_new ("GET", data->url);
-	
+		msg2 = soup_message_new ("GET", plugin->priv->url);
+
 		soup_session_queue_message (session, msg2,
 					    (SoupSessionCallback)parse_page_file,
-					    window);
-	}
-	else
-	{
-		g_object_set_data (G_OBJECT (window),
-				   WINDOW_DATA_KEY,
-				   NULL);
+					    plugin);
 	}
 }
 
 static void
-impl_activate (GeditPlugin *plugin,
-	       GeditWindow *window)
+gedit_check_update_plugin_activate (GeditWindowActivatable *activatable)
 {
+	GeditCheckUpdatePluginPrivate *priv;
 	SoupMessage *msg;
-	WindowData *data;
-	
+
 	gedit_debug (DEBUG_PLUGINS);
 
-	data = g_slice_new (WindowData);
-	data->plugin = GEDIT_CHECK_UPDATE_PLUGIN (plugin);
-	data->url = NULL;
-	data->version = NULL;
-
-	g_object_set_data_full (G_OBJECT (window),
-				WINDOW_DATA_KEY,
-				data,
-				free_window_data);
+	priv = GEDIT_CHECK_UPDATE_PLUGIN (activatable)->priv;
 
 	msg = soup_message_new ("GET", GEDIT_URL);
-	
-	soup_session_queue_message (GEDIT_CHECK_UPDATE_PLUGIN (plugin)->priv->session, msg,
+
+	soup_session_queue_message (priv->session, msg,
 				    (SoupSessionCallback)parse_page_version,
-				    window);
+				    activatable);
 }
 
 static void
-impl_deactivate (GeditPlugin *plugin,
-		 GeditWindow *window)
+gedit_check_update_plugin_deactivate (GeditWindowActivatable *activatable)
 {
 
 	gedit_debug (DEBUG_PLUGINS);
-	
-	soup_session_abort (GEDIT_CHECK_UPDATE_PLUGIN (plugin)->priv->session);
-	
-	g_object_set_data (G_OBJECT (window),
-			   WINDOW_DATA_KEY,
-			   NULL);
+
+	soup_session_abort (GEDIT_CHECK_UPDATE_PLUGIN (activatable)->priv->session);
 }
 
 static void
 gedit_check_update_plugin_class_init (GeditCheckUpdatePluginClass *klass)
 {
 	GObjectClass *object_class = G_OBJECT_CLASS (klass);
-	GeditPluginClass *plugin_class = GEDIT_PLUGIN_CLASS (klass);
-	
-	g_type_class_add_private (object_class, sizeof (GeditCheckUpdatePluginPrivate));
 
 	object_class->finalize = gedit_check_update_plugin_finalize;
 	object_class->dispose = gedit_check_update_plugin_dispose;
-
-	plugin_class->activate = impl_activate;
-	plugin_class->deactivate = impl_deactivate;
+	object_class->set_property = gedit_check_update_plugin_set_property;
+	object_class->get_property = gedit_check_update_plugin_get_property;
+	
+	g_object_class_override_property (object_class, PROP_WINDOW, "window");
+	
+	g_type_class_add_private (object_class, sizeof (GeditCheckUpdatePluginPrivate));
 }
-/* ex:ts=8:noet: */
+
+static void
+gedit_check_update_plugin_class_finalize (GeditCheckUpdatePluginClass *klass)
+{
+}
+
+static void
+gedit_window_activatable_iface_init (GeditWindowActivatableInterface *iface)
+{
+	iface->activate = gedit_check_update_plugin_activate;
+	iface->deactivate = gedit_check_update_plugin_deactivate;
+}
+
+G_MODULE_EXPORT void
+peas_register_types (PeasObjectModule *module)
+{
+	gedit_check_update_plugin_register_type (G_TYPE_MODULE (module));
+
+	peas_object_module_register_extension_type (module,
+						    GEDIT_TYPE_WINDOW_ACTIVATABLE,
+						    GEDIT_TYPE_CHECK_UPDATE_PLUGIN);
+}
+
+/* ex:set ts=8 noet: */
